@@ -15,6 +15,8 @@ import requests
 from homura import download
 from shapely.geometry import Polygon
 
+from osmcha.warnings import Warnings
+
 
 # Python 2 has 'failobj' instead of 'default'
 try:
@@ -268,21 +270,6 @@ class Analyse(object):
         self.excluded_words = excluded_words
         self.illegal_sources = illegal_sources
         self.suspect_words = suspect_words
-        self.enabled_warnings = {
-            'warnings:almost_junction': 'Almost junction',
-            'warnings:close_nodes': 'Very close points',
-            'warnings:crossing_ways': 'Crossing ways',
-            'warnings:disconnected_way': 'Disconnected way',
-            'warnings:generic_name': 'Generic name',
-            'warnings:impossible_oneway': 'Impossible oneway',
-            'warnings:incompatible_source': 'suspect_word',
-            'warnings:missing_role': 'Missing role',
-            'warnings:missing_tag': 'Missing tag',
-            'warnings:outdated_tags': 'Outdated tags',
-            'warnings:private_data': 'Private information',
-            'warnings:tag_suggests_area': 'Line tagged as area',
-            'warnings:unsquare_way': 'Unsquare corners',
-            }
 
     def set_fields(self, changeset):
         """Set the fields of this class with the metadata of the analysed
@@ -325,9 +312,10 @@ class Analyse(object):
             self.label_suspicious('Review requested')
 
     def verify_warning_tags(self):
-        for tag in self.warning_tags:
-            if tag in self.enabled_warnings.keys():
-                self.label_suspicious(self.enabled_warnings.get(tag))
+        w = Warnings()
+        for item in [w.is_enabled(reason) for reason in self.warning_tags]:
+            if item is not None:
+                self.label_suspicious(item)
 
     def verify_user(self):
         """Verify if the changeset was made by a inexperienced mapper (anyone
@@ -380,6 +368,7 @@ class Analyse(object):
                     'improveosm.org',
                     'strava.github.io',
                     'preview.ideditor.com',
+                    'ideditor.netlify.app',
                     'hey.mapbox.com',
                     'projets.pavie.info',
                     'maps.mapcat.com',
@@ -431,8 +420,7 @@ class Analyse(object):
         fields_to_remove = [
             'create_threshold', 'modify_threshold', 'illegal_sources',
             'delete_threshold', 'percentage', 'top_threshold', 'suspect_words',
-            'excluded_words', 'host', 'review_requested', 'warning_tags',
-            'enabled_warnings'
+            'excluded_words', 'host', 'review_requested', 'warning_tags'
             ]
         for field in fields_to_remove:
             ch_dict.pop(field)
